## Drupal 💙 Alpine.js


## How to use

This module exclusively uses the [Drupal Library system](https://www.drupal.org/docs/theming-drupal/adding-assets-css-js-to-a-drupal-theme-via-librariesyml#js-properties) to find and process javascript files that are either a [Alpine Plugin](https://alpinejs.dev/advanced/extending) or a script that needs to be loaded before Alpine.start is executed.
In order to add your script or scripts to be recognized by this module, you need to add an extra property to the attributes section of the .js file.


```yaml
drupal.alpine_plugin:
  version: VERSION
  js:
    js/drupal.itemsjs.js: { attributes: { alpine_js: true } }
  dependencies:
    - alpine_js/alpine_js
```

### Alpine Plugin
If your code contains a Alpine.js plugin you need to implement a listener for `alpine:init` event.

```js
const myPlugin = function (Alpine) {
  Alpine.directive('directive',(el) => {
    // The actual code of your directive
  });
}

document.addEventListener('alpine:init', () => {
    window.Alpine.plugin(myPlugin);
})
```


### Changelog

#### 3.0.0 
 - Tagged first release, we have been using this in production for the 1st quarter of 2023 without any issues.
 - Upgraded AlpineJS and AlpineJS-CSP to 3.12.0
 - Fixed a regression issue in the UI showing a false state that CSP version was enabled if you updated from an older dev release.
 - Dropped support for EOL Drupal version (9.3 and earlier)
 - Updated minimal PHP to 8.0 in composer.json as 7.4 is EOL
