<?php

namespace Drupal\alpine_js\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure AlpineJS Library support settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The config name used in this form.
   */
  static protected string $configName = 'alpine_js.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'alpinejs_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [self::$configName];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['footer'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Load AlpineJS in footer'),
      '#default_value' => $this->config('alpine_js.settings')
        ->get('footer') ?? TRUE,
      '#description' =>
      $this->t('Disable to load AlpineJS and related modules in the HEAD.'),
    ];
    $form['csp'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use the CSP save version of AlpineJS.'),
      '#default_value' => $this->config('alpine_js.settings')
        ->get('csp') ?? TRUE,
      '#description' =>
      $this->t('For more information see the <a href="https://alpinejs.dev/advanced/csp" target="_blank">documentation</a>.'),
    ];    
    $form['bridge'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Add Drupal to Alpinejs Bridge (experimental!)'),
      '#default_value' => $this->config('alpine_js.settings')
        ->get('bridge') ?? TRUE,
      '#description' =>
      $this->t('Additional support for Drupal. methods as Alpine Magics or Directives'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config(self::$configName)
      ->set('footer', $form_state->getValue('footer'))
      ->set('bridge', $form_state->getValue('bridge'))
      ->set('csp', $form_state->getValue('csp'))
      ->save();
    return parent::submitForm($form, $form_state);
  }

}
